@@ -25,7 +25,7 @@ def parse_ref(current_ref):
         raise Exception(f"Invalid ref `{current_ref}`!")  # noqa
 
     tag_name = current_ref.replace("refs/tags/", "")
-    print(tag_name)
+    print(tag_name)  # noqa
 
 
 if __name__ == "__main__":
