@@ -41,7 +41,6 @@ def convert(nb, to_version):
 
     # If the version exist, try to convert to it one step at a time.
     elif to_version in versions:
-
         # Get the the version that this recursion will convert to as a step
         # closer to the final revision.  Make sure the newer of the conversion
         # functions is used to perform the conversion.
@@ -56,13 +55,11 @@ def convert(nb, to_version):
             # Convert and make sure version changed during conversion.
             converted = convert_function(nb)
             if converted.get("nbformat", 1) == version:
-                raise ValueError(
-                    "Failed to convert notebook from v%d to v%d." % (version, step_version)
-                )
+                msg = "Failed to convert notebook from v%d to v%d." % (version, step_version)
+                raise ValueError(msg)
         except AttributeError as e:
-            raise ValidationError(
-                f"Notebook could not be converted from version {version} to version {step_version} because it's missing a key: {e}"
-            )
+            msg = f"Notebook could not be converted from version {version} to version {step_version} because it's missing a key: {e}"
+            raise ValidationError(msg) from None
 
         # Recursively convert until target version is reached.
         return convert(converted, to_version)
