@@ -9,11 +9,24 @@ import sys
 import typing as t
 from collections import OrderedDict
 from contextlib import contextmanager
-from datetime import datetime
+from datetime import datetime, timezone
 from hmac import HMAC
 
 try:
     import sqlite3
+
+    # Use adapters recommended by Python 3.12 stdlib docs.
+    # https://docs.python.org/3.12/library/sqlite3.html#default-adapters-and-converters-deprecated
+    def adapt_datetime_iso(val):
+        """Adapt datetime.datetime to timezone-naive ISO 8601 date."""
+        return val.isoformat()
+
+    def convert_datetime(val):
+        """Convert ISO 8601 datetime to datetime.datetime object."""
+        return datetime.fromisoformat(val.decode())
+
+    sqlite3.register_adapter(datetime, adapt_datetime_iso)
+    sqlite3.register_converter("datetime", convert_datetime)
 except ImportError:
     try:
         from pysqlite2 import dbapi2 as sqlite3  # type:ignore[no-redef]
@@ -23,18 +36,7 @@ except ImportError:
 from base64 import encodebytes
 
 from jupyter_core.application import JupyterApp, base_flags
-from traitlets import (
-    Any,
-    Bool,
-    Bytes,
-    Callable,
-    Enum,
-    Instance,
-    Integer,
-    Unicode,
-    default,
-    observe,
-)
+from traitlets import Any, Bool, Bytes, Callable, Enum, Instance, Integer, Unicode, default, observe
 from traitlets.config import LoggingConfigurable, MultipleInstanceError
 
 from . import NO_CONVERT, __version__, read, reads
@@ -84,11 +86,13 @@ class MemorySignatureStore(SignatureStore):
     cache_size = 65535
 
     def __init__(self):
+        """Initialize a memory signature store."""
         # We really only want an ordered set, but the stdlib has OrderedDict,
         # and it's easy to use a dict as a set.
         self.data = OrderedDict()
 
     def store_signature(self, digest, algorithm):
+        """Store a signature."""
         key = (digest, algorithm)
         # Pop it so it goes to the end when we reinsert it
         self.data.pop(key, None)
@@ -105,6 +109,7 @@ class MemorySignatureStore(SignatureStore):
             self.data.popitem(last=False)
 
     def check_signature(self, digest, algorithm):
+        """Check a signature."""
         key = (digest, algorithm)
         if key in self.data:
             # Move it to the end (.move_to_end() method is new in Py3)
@@ -114,6 +119,7 @@ class MemorySignatureStore(SignatureStore):
         return False
 
     def remove_signature(self, digest, algorithm):
+        """Remove a signature."""
         self.data.pop((digest, algorithm), None)
 
 
@@ -130,18 +136,20 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
     ).tag(config=True)
 
     def __init__(self, db_file, **kwargs):
+        """Initialize a sql signature store."""
         super().__init__(**kwargs)
         self.db_file = db_file
         self.db = self._connect_db(db_file)
 
     def close(self):
+        """Close the db."""
         if self.db is not None:
             self.db.close()
 
     def _connect_db(self, db_file):
-        kwargs: t.Dict[str, t.Any] = dict(
-            detect_types=sqlite3.PARSE_DECLTYPES | sqlite3.PARSE_COLNAMES
-        )
+        kwargs: t.Dict[str, t.Any] = {
+            "detect_types": sqlite3.PARSE_DECLTYPES | sqlite3.PARSE_COLNAMES
+        }
         db = None
         try:
             db = sqlite3.connect(db_file, **kwargs)
@@ -180,6 +188,7 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
         return db
 
     def init_db(self, db):
+        """Initialize the db."""
         db.execute(
             """
             CREATE TABLE IF NOT EXISTS nbsignatures
@@ -199,6 +208,7 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
         db.commit()
 
     def store_signature(self, digest, algorithm):
+        """Store a signature in the db."""
         if self.db is None:
             return
         if not self.check_signature(digest, algorithm):
@@ -207,7 +217,7 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
                 INSERT INTO nbsignatures (algorithm, signature, last_seen)
                 VALUES (?, ?, ?)
                 """,
-                (algorithm, digest, datetime.utcnow()),
+                (algorithm, digest, datetime.now(tz=timezone.utc)),
             )
         else:
             self.db.execute(
@@ -215,7 +225,7 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
                 algorithm = ? AND
                 signature = ?;
                 """,
-                (datetime.utcnow(), algorithm, digest),
+                (datetime.now(tz=timezone.utc), algorithm, digest),
             )
         self.db.commit()
 
@@ -225,6 +235,7 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
             self.cull_db()
 
     def check_signature(self, digest, algorithm):
+        """Check a signature against the db."""
         if self.db is None:
             return False
         r = self.db.execute(
@@ -241,12 +252,13 @@ class SQLiteSignatureStore(SignatureStore, LoggingConfigurable):
             algorithm = ? AND
             signature = ?;
             """,
-            (datetime.utcnow(), algorithm, digest),
+            (datetime.now(tz=timezone.utc), algorithm, digest),
         )
         self.db.commit()
         return True
 
     def remove_signature(self, digest, algorithm):
+        """Remove a signature from the db."""
         self.db.execute(
             """DELETE FROM nbsignatures WHERE
                 algorithm = ? AND
@@ -277,7 +289,7 @@ def yield_everything(obj):
     if isinstance(obj, dict):
         for key in sorted(obj):
             value = obj[key]
-            assert isinstance(key, str)
+            assert isinstance(key, str)  # noqa
             yield key.encode()
             yield from yield_everything(value)
     elif isinstance(obj, (list, tuple)):
@@ -294,11 +306,11 @@ def yield_code_cells(nb):
 
     nbformat version independent
     """
-    if nb.nbformat >= 4:
+    if nb.nbformat >= 4:  # noqa
         for cell in nb["cells"]:
             if cell["cell_type"] == "code":
                 yield cell
-    elif nb.nbformat == 3:
+    elif nb.nbformat == 3:  # noqa
         for ws in nb["worksheets"]:
             for cell in ws["cells"]:
                 if cell["cell_type"] == "code":
@@ -369,7 +381,9 @@ class NotebookNotary(LoggingConfigurable):
         return os.path.join(self.data_dir, "nbsignatures.db")
 
     algorithm = Enum(
-        algorithms, default_value="sha256", help="""The hashing algorithm used to sign notebooks."""
+        algorithms,
+        default_value="sha256",
+        help="""The hashing algorithm used to sign notebooks.""",
     ).tag(config=True)
 
     @observe("algorithm")
@@ -404,6 +418,7 @@ class NotebookNotary(LoggingConfigurable):
             return secret
 
     def __init__(self, **kwargs):
+        """Initialize the notary."""
         super().__init__(**kwargs)
         self.store = self.store_factory()
 
@@ -446,7 +461,7 @@ class NotebookNotary(LoggingConfigurable):
         - the requested scheme is available from hashlib
         - the computed hash from notebook_signature matches the stored hash
         """
-        if nb.nbformat < 3:
+        if nb.nbformat < 3:  # noqa
             return False
         signature = self.compute_signature(nb)
         return self.store.check_signature(signature, self.algorithm)
@@ -456,7 +471,7 @@ class NotebookNotary(LoggingConfigurable):
 
         Stores hash algorithm and hmac digest in a local database of trusted notebooks.
         """
-        if nb.nbformat < 3:
+        if nb.nbformat < 3:  # noqa
             return
         signature = self.compute_signature(nb)
         self.store.store_signature(signature, self.algorithm)
@@ -478,7 +493,7 @@ class NotebookNotary(LoggingConfigurable):
 
         This function is the inverse of check_cells
         """
-        if nb.nbformat < 3:
+        if nb.nbformat < 3:  # noqa
             return
 
         for cell in yield_code_cells(nb):
@@ -500,7 +515,7 @@ class NotebookNotary(LoggingConfigurable):
             return True
 
         # explicitly safe output
-        if nbformat_version >= 4:
+        if nbformat_version >= 4:  # noqa
             unsafe_output_types = ["execute_result", "display_data"]
             safe_keys = {"output_type", "execution_count", "metadata"}
         else:  # v3
@@ -526,7 +541,7 @@ class NotebookNotary(LoggingConfigurable):
 
         This function is the inverse of mark_cells.
         """
-        if nb.nbformat < 3:
+        if nb.nbformat < 3:  # noqa
             return False
         trusted = True
         for cell in yield_code_cells(nb):
@@ -537,7 +552,7 @@ class NotebookNotary(LoggingConfigurable):
         return trusted
 
 
-trust_flags = {
+trust_flags: dict = {
     "reset": (
         {"TrustNotebookApp": {"reset": True}},
         """Delete the trusted notebook cache.
@@ -549,6 +564,8 @@ trust_flags.update(base_flags)
 
 
 class TrustNotebookApp(JupyterApp):
+    """An application for handling notebook trust."""
+
     version = __version__
     description = """Sign one or more Jupyter notebooks with your key,
     to trust their dynamic (HTML, Javascript) output.
@@ -592,27 +609,28 @@ class TrustNotebookApp(JupyterApp):
     def sign_notebook(self, nb, notebook_path="<stdin>"):
         """Sign a notebook that's been loaded"""
         if self.notary.check_signature(nb):
-            print("Notebook already signed: %s" % notebook_path)
+            print("Notebook already signed: %s" % notebook_path)  # noqa
         else:
-            print("Signing notebook: %s" % notebook_path)
+            print("Signing notebook: %s" % notebook_path)  # noqa
             self.notary.sign(nb)
 
     def generate_new_key(self):
         """Generate a new notebook signature key"""
-        print("Generating new notebook key: %s" % self.notary.secret_file)
+        print("Generating new notebook key: %s" % self.notary.secret_file)  # noqa
         self.notary._write_secret_file(os.urandom(1024))
 
     def start(self):
+        """Start the trust notebook app."""
         if self.reset:
             if os.path.exists(self.notary.db_file):
-                print("Removing trusted signature cache: %s" % self.notary.db_file)
+                print("Removing trusted signature cache: %s" % self.notary.db_file)  # noqa
                 os.remove(self.notary.db_file)
             self.generate_new_key()
             return
         if not self.extra_args:
             self.log.debug("Reading notebook from stdin")
             nb_s = sys.stdin.read()
-            assert isinstance(nb_s, str)
+            assert isinstance(nb_s, str)  # noqa
             nb = reads(nb_s, NO_CONVERT)
             self.sign_notebook(nb, "<stdin>")
         else:
