@@ -9,7 +9,7 @@ Authors:
 #  Copyright (C) 2008-2011  The IPython Development Team
 #
 #  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
+#  the file LICENSE, distributed as part of this software.
 # -----------------------------------------------------------------------------
 
 # -----------------------------------------------------------------------------
@@ -30,14 +30,20 @@ _encoding_declaration_re = re.compile(r"^#.*coding[:=]\s*([-\w.]+)")
 
 
 class PyReaderError(Exception):
+    """An error raised by the PyReader."""
+
     pass
 
 
 class PyReader(NotebookReader):
+    """A Python notebook reader."""
+
     def reads(self, s, **kwargs):
+        """Convert a string to a notebook."""
         return self.to_notebook(s, **kwargs)
 
-    def to_notebook(self, s, **kwargs):
+    def to_notebook(self, s, **kwargs):  # noqa
+        """Convert a string to a notebook."""
         lines = s.splitlines()
         cells = []
         cell_lines: List[str] = []
@@ -74,11 +80,12 @@ class PyReader(NotebookReader):
         return nb
 
     def new_cell(self, state, lines):
+        """Create a new cell."""
         if state == "codecell":
-            input = "\n".join(lines)
-            input = input.strip("\n")
-            if input:
-                return new_code_cell(input=input)
+            input_ = "\n".join(lines)
+            input_ = input_.strip("\n")
+            if input_:
+                return new_code_cell(input=input_)
         elif state == "htmlcell":
             text = self._remove_comments(lines)
             if text:
@@ -100,6 +107,7 @@ class PyReader(NotebookReader):
         return text
 
     def split_lines_into_blocks(self, lines):
+        """Split lines into code blocks."""
         if len(lines) == 1:
             yield lines[0]
             raise StopIteration()
@@ -114,28 +122,31 @@ class PyReader(NotebookReader):
 
 
 class PyWriter(NotebookWriter):
+    """A Python notebook writer."""
+
     def writes(self, nb, **kwargs):
+        """Convert a notebook object to a string."""
         lines = ["# -*- coding: utf-8 -*-"]
         lines.extend(["# <nbformat>2</nbformat>", ""])
         for ws in nb.worksheets:
             for cell in ws.cells:
                 if cell.cell_type == "code":
-                    input = cell.get("input")
-                    if input is not None:
+                    input_ = cell.get("input")
+                    if input_ is not None:
                         lines.extend(["# <codecell>", ""])
-                        lines.extend(input.splitlines())
+                        lines.extend(input_.splitlines())
                         lines.append("")
                 elif cell.cell_type == "html":
-                    input = cell.get("source")
-                    if input is not None:
+                    input_ = cell.get("source")
+                    if input_ is not None:
                         lines.extend(["# <htmlcell>", ""])
-                        lines.extend(["# " + line for line in input.splitlines()])
+                        lines.extend(["# " + line for line in input_.splitlines()])
                         lines.append("")
                 elif cell.cell_type == "markdown":
-                    input = cell.get("source")
-                    if input is not None:
+                    input_ = cell.get("source")
+                    if input_ is not None:
                         lines.extend(["# <markdowncell>", ""])
-                        lines.extend(["# " + line for line in input.splitlines()])
+                        lines.extend(["# " + line for line in input_.splitlines()])
                         lines.append("")
         lines.append("")
         return str("\n".join(lines))
