@@ -9,7 +9,7 @@ Authors:
 #  Copyright (C) 2008-2011  The IPython Development Team
 #
 #  Distributed under the terms of the BSD License.  The full license is in
-#  the file COPYING, distributed as part of this software.
+#  the file LICENSE, distributed as part of this software.
 # -----------------------------------------------------------------------------
 
 # -----------------------------------------------------------------------------
@@ -145,7 +145,8 @@ class NotebookReader:
 
     def reads(self, s, **kwargs):
         """Read a notebook from a string."""
-        raise NotImplementedError("loads must be implemented in a subclass")
+        msg = "loads must be implemented in a subclass"
+        raise NotImplementedError(msg)
 
     def read(self, fp, **kwargs):
         """Read a notebook from a file like object"""
@@ -157,7 +158,8 @@ class NotebookWriter:
 
     def writes(self, nb, **kwargs):
         """Write a notebook to a string."""
-        raise NotImplementedError("loads must be implemented in a subclass")
+        msg = "loads must be implemented in a subclass"
+        raise NotImplementedError(msg)
 
     def write(self, nb, fp, **kwargs):
         """Write a notebook to a file like object"""
