@@ -202,8 +202,7 @@ class NotebookValidationError(ValidationError):
             [
                 error.message,
                 "",
-                "Failed validating %r in %s%s:"
-                % (
+                "Failed validating {!r} in {}{}:".format(
                     error.validator,
                     self.ref or "notebook",
                     _format_as_index(list(error.relative_schema_path)[:-1]),
@@ -524,7 +523,7 @@ def _get_errors(
     return iter(errors)
 
 
-def _strip_invalida_metadata(
+def _strip_invalida_metadata(  # noqa
     nbdict: Any, version: int, version_minor: int, relax_add_props: bool
 ) -> int:
     """
