@@ -10,7 +10,7 @@ class TestPy(formattest.NBFormatTest, TestCase):
     nb0_ref = nb0_py
     ext = "py"
     mod = nbpy
-    ignored_keys = ["collapsed", "outputs", "prompt_number", "metadata"]
+    ignored_keys = ["collapsed", "outputs", "prompt_number", "metadata"]  # noqa
 
     def assertSubset(self, da, db):
         """assert that da is a subset of db, ignoring self.ignored_keys.
